mix'EM 
======

mixem is a pure-python implementation of the Expectation-Maximization (EM) algorithm for fitting mixtures of probability distributions. It works in Python 2 and Python 3 (tested with 2.7 and 3.5.1).

Features
--------

* Built-in support for several probability distributions
* Easily define custom probability distributions implementing their PDF and weighted log-likelihood

Dependencies
------------

* NumPy v1.7.0 or newer
* SciPy v0.14.0 or newer

Installation
------------

::

    pip install mixem
